<a href="./_static/lab/index.html?path=README.ipynb" target="_blank" style="float: right;">
    <i class="fa-solid fa-external-link"></i>
    Open in new tab
</a>

<iframe
    src="./_static/lab/index.html?path=README.ipynb"
    style="width: 99%; border: solid 1px #999; height: 500px"
></iframe>

```{include} ../README.md

```

```{include} ../CHANGELOG.md

```

```{include} ../CONTRIBUTING.md

```

## Open Source

```{include} ../LICENSE

```
